@@ -41,7 +41,8 @@ module IssuableCollections
     return if pagination_disabled?
 
     @issuables          = @issuables.page(params[:page])
-    @issuable_meta_data = issuable_meta_data(@issuables, collection_type)
+    @issuables          = per_page_for_relative_position if params[:sort] == 'relative_position'
+    @issuable_meta_data = issuable_meta_data(@issuables, collection_type, current_user)
     @total_pages        = issuable_page_count
   end
   # rubocop:enable Gitlab/ModuleWithInstanceVariables
@@ -80,6 +81,11 @@ module IssuableCollections
     (row_count.to_f / limit).ceil
   end
 
+  # manual / relative_position sorting allows for 100 items on the page
+  def per_page_for_relative_position
+    @issuables.per(100) # rubocop:disable Gitlab/ModuleWithInstanceVariables
+  end
+
   def issuable_finder_for(finder_class)
     finder_class.new(current_user, finder_options)
   end
