@@ -17,7 +17,7 @@ class Profiles::AccountsController < Profiles::ApplicationController
     if unlink_provider_allowed?(provider)
       identity.destroy
     else
-      flash[:alert] = "You are not allowed to unlink your primary login account"
+      flash[:alert] = _("You are not allowed to unlink your primary login account")
     end
 
     redirect_to profile_account_path
