@@ -15,7 +15,7 @@ class ProfilesController < Profiles::ApplicationController
       result = Users::UpdateService.new(current_user, user_params.merge(user: @user)).execute
 
       if result[:status] == :success
-        message = "Profile was successfully updated"
+        message = s_("Profiles|Profile was successfully updated")
 
         format.html { redirect_back_or_default(default: { action: 'show' }, options: { notice: message }) }
         format.json { render json: { message: message } }
@@ -31,7 +31,7 @@ class ProfilesController < Profiles::ApplicationController
       user.reset_incoming_email_token!
     end
 
-    flash[:notice] = "Incoming email token was successfully reset"
+    flash[:notice] = s_("Profiles|Incoming email token was successfully reset")
 
     redirect_to profile_personal_access_tokens_path
   end
@@ -41,7 +41,7 @@ class ProfilesController < Profiles::ApplicationController
       user.reset_feed_token!
     end
 
-    flash[:notice] = 'Feed token was successfully reset'
+    flash[:notice] = s_('Profiles|Feed token was successfully reset')
 
     redirect_to profile_personal_access_tokens_path
   end
