@@ -1,11 +1,13 @@
 # frozen_string_literal: true
 
 class Projects::ClustersController < Clusters::ClustersController
-  include ProjectUnauthorized
-
   prepend_before_action :project
   before_action :repository
 
+  before_action do
+    push_frontend_feature_flag(:prometheus_computed_alerts)
+  end
+
   layout 'project'
 
   private
@@ -15,7 +17,7 @@ class Projects::ClustersController < Clusters::ClustersController
   end
 
   def project
-    @project ||= find_routable!(Project, File.join(params[:namespace_id], params[:project_id]), not_found_or_authorized_proc: project_unauthorized_proc)
+    @project ||= find_routable!(Project, File.join(params[:namespace_id], params[:project_id]))
   end
 
   def repository
