@@ -29,15 +29,18 @@ module Types
       # proc because we set complexity depending on arguments and number of
       # items which can be loaded.
       proc do |ctx, args, child_complexity|
-        page_size = @max_page_size || ctx.schema.default_max_page_size
-        limit_value = [args[:first], args[:last], page_size].compact.min
-
         # Resolvers may add extra complexity depending on used arguments
-        complexity = child_complexity + self.resolver&.try(:resolver_complexity, args).to_i
+        complexity = child_complexity + self.resolver&.try(:resolver_complexity, args, child_complexity: child_complexity).to_i
 
-        # Resolvers may add extra complexity depending on number of items being loaded.
-        multiplier = self.resolver&.try(:complexity_multiplier, args).to_f
-        complexity += complexity * limit_value * multiplier
+        field_defn = to_graphql
+
+        if field_defn.connection?
+          # Resolvers may add extra complexity depending on number of items being loaded.
+          page_size   = field_defn.connection_max_page_size || ctx.schema.default_max_page_size
+          limit_value = [args[:first], args[:last], page_size].compact.min
+          multiplier  = self.resolver&.try(:complexity_multiplier, args).to_f
+          complexity += complexity * limit_value * multiplier
+        end
 
         complexity.to_i
       end
