@@ -57,12 +57,6 @@ module EmailsHelper
     pluralize(valid_length, unit)
   end
 
-  def reset_token_expire_message
-    link_tag = link_to('request a new one', new_user_password_url(user_email: @user.email))
-    "This link is valid for #{password_reset_token_valid_time}.  " \
-    "After it expires, you can #{link_tag}."
-  end
-
   def header_logo
     if current_appearance&.header_logo?
       image_tag(
@@ -91,6 +85,29 @@ module EmailsHelper
     ].join(';')
   end
 
+  def closure_reason_text(closed_via, format: nil)
+    case closed_via
+    when MergeRequest
+      merge_request = MergeRequest.find(closed_via[:id]).present
+
+      case format
+      when :html
+        merge_request_link = link_to(merge_request.to_reference, merge_request.web_url)
+        _("via merge request %{link}").html_safe % { link: merge_request_link }
+      else
+        # If it's not HTML nor text then assume it's text to be safe
+        _("via merge request %{link}") % { link: "#{merge_request.to_reference} (#{merge_request.web_url})" }
+      end
+    when String
+      # Technically speaking this should be Commit but per
+      # https://gitlab.com/gitlab-org/gitlab-ce/merge_requests/15610#note_163812339
+      # we can't deserialize Commit without custom serializer for ActiveJob
+      _("via %{closed_via}") % { closed_via: closed_via }
+    else
+      ""
+    end
+  end
+
   # "You are receiving this email because #{reason}"
   def notification_reason_text(reason)
     string = case reason
