@@ -1,5 +1,7 @@
 # frozen_string_literal: true
 
+require 'securerandom'
+
 module Clusters
   module Applications
     class Jupyter < ApplicationRecord
@@ -39,7 +41,7 @@ module Clusters
       end
 
       # Will be addressed in future MRs
-      # We need to investigate and document what will be permenantly deleted.
+      # We need to investigate and document what will be permanently deleted.
       def allowed_to_uninstall?
         false
       end
@@ -59,6 +61,10 @@ module Clusters
         "http://#{hostname}/hub/oauth_callback"
       end
 
+      def oauth_scopes
+        'api read_repository write_repository'
+      end
+
       private
 
       def specification
@@ -80,6 +86,9 @@ module Clusters
             "secretToken" => secret_token
           },
           "auth" => {
+            "state" => {
+              "cryptoKey" => crypto_key
+            },
             "gitlab" => {
               "clientId" => oauth_application.uid,
               "clientSecret" => oauth_application.secret,
@@ -89,12 +98,17 @@ module Clusters
           },
           "singleuser" => {
             "extraEnv" => {
-              "GITLAB_CLUSTER_ID" => cluster.id.to_s
+              "GITLAB_CLUSTER_ID" => cluster.id.to_s,
+              "GITLAB_HOST" => gitlab_host
             }
           }
         }
       end
 
+      def crypto_key
+        @crypto_key ||= SecureRandom.hex(32)
+      end
+
       def project_id
         cluster&.project&.id
       end
@@ -103,6 +117,10 @@ module Clusters
         Gitlab.config.gitlab.url
       end
 
+      def gitlab_host
+        Gitlab.config.gitlab.host
+      end
+
       def content_values
         YAML.load_file(chart_values_file).deep_merge!(specification)
       end
