@@ -75,4 +75,11 @@ module Taskable
   def task_status_short
     task_status(short: true)
   end
+
+  def task_completion_status
+    @task_completion_status ||= {
+        count: tasks.summary.item_count,
+        completed_count: tasks.summary.complete_count
+    }
+  end
 end
