@@ -58,6 +58,7 @@ class Issue < ApplicationRecord
   scope :order_due_date_asc, -> { reorder('issues.due_date IS NULL, issues.due_date ASC') }
   scope :order_due_date_desc, -> { reorder('issues.due_date IS NULL, issues.due_date DESC') }
   scope :order_closest_future_date, -> { reorder('CASE WHEN issues.due_date >= CURRENT_DATE THEN 0 ELSE 1 END ASC, ABS(CURRENT_DATE - issues.due_date) ASC') }
+  scope :order_relative_position_asc, -> { reorder(::Gitlab::Database.nulls_last_order('relative_position', 'ASC')) }
 
   scope :preload_associations, -> { preload(:labels, project: :namespace) }
   scope :with_api_entity_associations, -> { preload(:timelogs, :assignees, :author, :notes, :labels, project: [:route, { namespace: :route }] ) }
@@ -130,9 +131,10 @@ class Issue < ApplicationRecord
   def self.sort_by_attribute(method, excluded_labels: [])
     case method.to_s
     when 'closest_future_date' then order_closest_future_date
-    when 'due_date'      then order_due_date_asc
-    when 'due_date_asc'  then order_due_date_asc
-    when 'due_date_desc' then order_due_date_desc
+    when 'due_date'            then order_due_date_asc
+    when 'due_date_asc'        then order_due_date_asc
+    when 'due_date_desc'       then order_due_date_desc
+    when 'relative_position'   then order_relative_position_asc
     else
       super
     end
@@ -248,8 +250,12 @@ class Issue < ApplicationRecord
   end
   # rubocop: enable CodeReuse/ServiceClass
 
-  def merge_requests_count
-    merge_requests_closing_issues.count
+  def merge_requests_count(user = nil)
+    ::MergeRequestsClosingIssues.count_for_issue(self.id, user)
+  end
+
+  def labels_hook_attrs
+    labels.map(&:hook_attrs)
   end
 
   private
