@@ -4,11 +4,20 @@ class ProjectStatistics < ApplicationRecord
   belongs_to :project
   belongs_to :namespace
 
+  default_value_for :wiki_size, 0
+
+  # older migrations fail due to non-existent attribute without this
+  def wiki_size
+    has_attribute?(:wiki_size) ? super : 0
+  end
+
   before_save :update_storage_size
 
-  COLUMNS_TO_REFRESH = [:repository_size, :lfs_objects_size, :commit_count].freeze
+  COLUMNS_TO_REFRESH = [:repository_size, :wiki_size, :lfs_objects_size, :commit_count].freeze
   INCREMENTABLE_COLUMNS = { build_artifacts_size: %i[storage_size], packages_size: %i[storage_size] }.freeze
 
+  scope :for_project_ids, ->(project_ids) { where(project_id: project_ids) }
+
   def total_repository_size
     repository_size + lfs_objects_size
   end
@@ -27,22 +36,25 @@ class ProjectStatistics < ApplicationRecord
     self.commit_count = project.repository.commit_count
   end
 
-  # Repository#size needs to be converted from MB to Byte.
   def update_repository_size
     self.repository_size = project.repository.size * 1.megabyte
   end
 
+  def update_wiki_size
+    self.wiki_size = project.wiki.repository.size * 1.megabyte
+  end
+
   def update_lfs_objects_size
     self.lfs_objects_size = project.lfs_objects.sum(:size)
   end
 
   # older migrations fail due to non-existent attribute without this
   def packages_size
-    has_attribute?(:packages_size) ? super.to_i : 0
+    has_attribute?(:packages_size) ? super : 0
   end
 
   def update_storage_size
-    self.storage_size = repository_size + lfs_objects_size + build_artifacts_size + packages_size
+    self.storage_size = repository_size + wiki_size.to_i + lfs_objects_size + build_artifacts_size + packages_size
   end
 
   # Since this incremental update method does not call update_storage_size above,
