@@ -21,11 +21,7 @@ module Clusters
     private_class_method :projects_with_missing_kubernetes_namespaces_for_cluster
 
     def self.clusters_with_missing_kubernetes_namespaces_for_project(project)
-      if Feature.enabled?(:ci_preparing_state, default_enabled: true)
-        project.clusters.managed.missing_kubernetes_namespace(project.kubernetes_namespaces)
-      else
-        project.all_clusters.managed.missing_kubernetes_namespace(project.kubernetes_namespaces)
-      end
+      project.clusters.managed.missing_kubernetes_namespace(project.kubernetes_namespaces)
     end
 
     private_class_method :clusters_with_missing_kubernetes_namespaces_for_project
