@@ -74,6 +74,8 @@ class PostReceive
 
   def process_wiki_changes(post_received)
     post_received.project.touch(:last_activity_at, :last_repository_updated_at)
+    post_received.project.wiki.repository.expire_statistics_caches
+    ProjectCacheWorker.perform_async(post_received.project.id, [], [:wiki_size])
   end
 
   def log(message)
