@@ -6,27 +6,12 @@ module API
   class Projects < Grape::API
     include PaginationParams
     include Helpers::CustomAttributes
-    include Helpers::ProjectsHelpers
+
+    helpers Helpers::ProjectsHelpers
 
     before { authenticate_non_get! }
 
     helpers do
-      if Gitlab.ee?
-        params :optional_filter_params_ee do
-          optional :wiki_checksum_failed, type: Grape::API::Boolean, default: false, desc: 'Limit by projects where wiki checksum is failed'
-          optional :repository_checksum_failed, type: Grape::API::Boolean, default: false, desc: 'Limit by projects where repository checksum is failed'
-        end
-
-        params :optional_update_params_ee do
-          optional :mirror_user_id, type: Integer, desc: 'User responsible for all the activity surrounding a pull mirror event'
-          optional :only_mirror_protected_branches, type: Grape::API::Boolean, desc: 'Only mirror protected branches'
-          optional :mirror_overwrites_diverged_branches, type: Grape::API::Boolean, desc: 'Pull mirror overwrites diverged branches'
-          optional :import_url, type: String, desc: 'URL from which the project is imported'
-          optional :packages_enabled, type: Grape::API::Boolean, desc: 'Enable project packages feature'
-          optional :fallback_approvals_required, type: Integer, desc: 'Overall approvals required when no rule is present'
-        end
-      end
-
       # EE::API::Projects would override this method
       def apply_filters(projects)
         projects = projects.with_issues_available_for_user(current_user) if params[:with_issues_enabled]
@@ -77,7 +62,7 @@ module API
         optional :with_programming_language, type: String, desc: 'Limit to repositories which use the given programming language'
         optional :min_access_level, type: Integer, values: Gitlab::Access.all_values, desc: 'Limit by minimum access level of authenticated user'
 
-        use :optional_filter_params_ee if Gitlab.ee?
+        use :optional_filter_params_ee
       end
 
       params :create_params do
@@ -296,7 +281,7 @@ module API
         optional :path, type: String, desc: 'The path of the repository'
 
         use :optional_project_params
-        use :optional_update_params_ee if Gitlab.ee?
+        use :optional_update_params_ee
 
         at_least_one_of(*Helpers::ProjectsHelpers.update_params_at_least_one_of)
       end
