@@ -7,7 +7,7 @@ module Gitlab
   class UserExtractor
     # Not using `Devise.email_regexp` to filter out any chars that an email
     # does not end with and not pinning the email to a start of end of a string.
-    EMAIL_REGEXP = /(?<email>([^@\s]+@[^@\s]+(?<!\W)))/
+    EMAIL_REGEXP = /(?<email>([^@\s]+@[^@\s]+(?<!\W)))/.freeze
     USERNAME_REGEXP = User.reference_pattern
 
     def initialize(text)
